##  Establish Clear Sources of Truth
Acknowledge that Collibra is the single source of truth for all data, while SAP LeanIX is the single source of truth for applications, business capabilities, interfaces, and their relationships to data objects. This alignment from the outset avoides discussions in the future over where to establish relationships between data objects and applications. Since SAP LeanIX is the source of truth for applications, the associations to data objects should also be maintained there. This ensures that any changes in the application landscape are reflected in the data objects and synced back to Collibra, keeping both systems up to date.
